@@ -14,6 +14,12 @@ from msldap.ldap_objects.adou import MSADOU, MSADOU_ATTRS
 from msldap.ldap_objects.adgpo import MSADGPO, MSADGPO_ATTRS
 from msldap.ldap_objects.adtrust import MSADDomainTrust, MSADDomainTrust_ATTRS
 from msldap.ldap_objects.adschemaentry import MSADSCHEMAENTRY_ATTRS, MSADSchemaEntry
+from msldap.ldap_objects.adca import MSADCA, MSADCA_ATTRS
+from msldap.ldap_objects.adenrollmentservice import MSADEnrollmentService_ATTRS, MSADEnrollmentService
+from msldap.ldap_objects.adcertificatetemplate import MSADCertificateTemplate, MSADCertificateTemplate_ATTRS
+from msldap.ldap_objects.adgmsa import MSADGMSAUser, MSADGMSAUser_ATTRS
+from msldap.ldap_objects.adcontainer import MSADContainer, MSADContainer_ATTRS
+
 
 __all__ = [
     'MSADUser', 
@@ -37,4 +43,15 @@ __all__ = [
     'MSADOU_ATTRS',
     'MSADSCHEMAENTRY_ATTRS',
     'MSADSchemaEntry',
+    'MSADCA',
+    'MSADCA_ATTRS',
+    'MSADEnrollmentService_ATTRS',
+    'MSADEnrollmentService',
+    'MSADCertificateTemplate', 
+    'MSADCertificateTemplate_ATTRS',
+    'MSADGMSAUser', 
+    'MSADGMSAUser_ATTRS',
+    'MSADContainer',
+    'MSADContainer_ATTRS',
+
 ]
\ No newline at end of file
